use crate::error_template::{AppError, ErrorTemplate};
use leptos::*;
use leptos_meta::*;
use leptos_router::*;

use crate::components;
use crate::pages;
use crate::util;

#[component]
pub fn App() -> impl IntoView {
    // Provides context that manages stylesheets, titles, meta tags, etc.
    provide_meta_context();
    let once = create_resource(
        || (),
        |_| async move { util::surrealdb::init_participants().await },
    );

    view! {
        // injects a stylesheet into the document <head>
        // id=leptos means cargo-leptos will hot-reload this stylesheet
        <Stylesheet id="leptos" href="/pkg/application.css"/>

        // sets the document title
        <Title text="WRB Timings"/>

        // content for this welcome page
        <Router fallback=|| {
            let mut outside_errors = Errors::default();
            outside_errors.insert_with_default_key(AppError::NotFound);
            view! {
                <ErrorTemplate outside_errors/>
            }
            .into_view()
        }>
            <components::header::Header />
            <main>
                {move || match once.get() {
                    None => view! { <p>"Loading"</p> }.into_view(),
                    Some(_) => view! {
                        <Routes>
                            <Route path="" view=pages::index::HomePage/>
                            <Route path="/add-participant" view=pages::add_participant::AddParticipant />
                            <Route path="/add-time" view=pages::add_time::AddTime />
                        </Routes>
                    }.into_view()
                }}
            </main>
        </Router>
    }
}
